==> re-admin-0.17.1.tgz: package/es/stores/DataDetailStore.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor;

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

import { observable, computed, action, runInAction, toJS } from 'mobx';
import { omitBy, isUndefined } from '../utils/fp';
import BaseDataStore from './BaseDataStore';
import joinKeys from '../utils/joinKeys';

var DataDetailStore = (_class = function (_BaseDataStore) {
	_inherits(DataDetailStore, _BaseDataStore);

	function DataDetailStore() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, DataDetailStore);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DataDetailStore.__proto__ || Object.getPrototypeOf(DataDetailStore)).call.apply(_ref, [this].concat(args))), _this), _initDefineProp(_this, 'isFetching', _descriptor, _this), _this.cache = observable.map(), _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(DataDetailStore, [{
		key: 'fetch',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
				var _this2 = this;

				var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

				var _options$query, query, method, _options$url, url, body, headers, cacheKey, fetchOptions, res, data;

				return regeneratorRuntime.wrap(function _callee$(_context) {
					while (1) {
						switch (_context.prev = _context.next) {
							case 0:
								_options$query = options.query, query = _options$query === undefined ? {} : _options$query, method = options.method, _options$url = options.url, url = _options$url === undefined ? joinKeys(this.selectedKeys) : _options$url, body = options.body, headers = options.headers;
								cacheKey = this.cacheKey;

								if (!this.cache.has(cacheKey)) {
									_context.next = 4;
									break;
								}

								return _context.abrupt('return', this.cache.get(cacheKey));

							case 4:

								this.isFetching = true;

								fetchOptions = {
									method: method,
									url: url,
									body: body,
									headers: headers,
									query: query
								};
								_context.next = 8;
								return this.request(omitBy(fetchOptions, isUndefined));

							case 8:
								res = _context.sent;
								_context.next = 11;
								return this.config.mapOnFetchOneResponse(res);

							case 11:
								data = _context.sent;

								runInAction(function () {
									_this2.cache.set(cacheKey, data);
									_this2.isFetching = false;
								});
								return _context.abrupt('return', data);

							case 14:
							case 'end':
								return _context.stop();
						}
					}
				}, _callee, this);
			}));

			function fetch() {
				return _ref2.apply(this, arguments);
			}

			return fetch;
		}()
	}, {
		key: 'setSelectedKeys',
		value: function setSelectedKeys(keys) {
			this.selectedKeys = keys;
		}
	}, {
		key: 'refresh',
		value: function refresh() {
			this.cache.clear();
			this.fetch();
		}
	}, {
		key: 'getData',
		value: function getData() {
			return this.data;
		}
	}, {
		key: 'cacheKey',
		get: function get() {
			return JSON.stringify(toJS(this.query));
		}
	}, {
		key: 'data',
		get: function get() {
			return this.cache.get(this.cacheKey);
		}
	}]);

	return DataDetailStore;
}(BaseDataStore), (_descriptor = _applyDecoratedDescriptor(_class.prototype, 'isFetching', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return false;
	}
}), _applyDecoratedDescriptor(_class.prototype, 'cacheKey', [computed], Object.getOwnPropertyDescriptor(_class.prototype, 'cacheKey'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'data', [computed], Object.getOwnPropertyDescriptor(_class.prototype, 'data'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'fetch', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'fetch'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'setSelectedKeys', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'setSelectedKeys'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'refresh', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'refresh'), _class.prototype)), _class);
export { DataDetailStore as default };

==> re-admin-0.19.0-0.tgz: package/es/stores/DataDetailStore.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class, _descriptor;

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _initDefineProp(target, property, descriptor, context) {
	if (!descriptor) return;
	Object.defineProperty(target, property, {
		enumerable: descriptor.enumerable,
		configurable: descriptor.configurable,
		writable: descriptor.writable,
		value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	});
}

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

function _initializerWarningHelper(descriptor, context) {
	throw new Error('Decorating class property failed. Please ensure that transform-class-properties is enabled.');
}

import { observable, computed, action, runInAction, toJS } from 'mobx';
import { omitBy, isUndefined } from '../utils/fp';
import BaseDataStore from './BaseDataStore';
import joinKeys from '../utils/joinKeys';

var DataDetailStore = (_class = function (_BaseDataStore) {
	_inherits(DataDetailStore, _BaseDataStore);

	function DataDetailStore() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, DataDetailStore);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DataDetailStore.__proto__ || Object.getPrototypeOf(DataDetailStore)).call.apply(_ref, [this].concat(args))), _this), _initDefineProp(_this, 'isFetching', _descriptor, _this), _this.cache = observable.map(), _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(DataDetailStore, [{
		key: 'fetch',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
				var _this2 = this;

				var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

				var _options$query, query, method, _options$url, url, body, headers, cacheKey, _config, mapOnFetchOneRequest, mapOnFetchOneResponse, fetchOptions, res, data;

				return regeneratorRuntime.wrap(function _callee$(_context) {
					while (1) {
						switch (_context.prev = _context.next) {
							case 0:
								_options$query = options.query, query = _options$query === undefined ? {} : _options$query, method = options.method, _options$url = options.url, url = _options$url === undefined ? joinKeys(this.selectedKeys) : _options$url, body = options.body, headers = options.headers;
								cacheKey = this.cacheKey, _config = this.config, mapOnFetchOneRequest = _config.mapOnFetchOneRequest, mapOnFetchOneResponse = _config.mapOnFetchOneResponse;

								if (!this.cache.has(cacheKey)) {
									_context.next = 4;
									break;
								}

								return _context.abrupt('return', this.cache.get(cacheKey));

							case 4:

								this.isFetching = true;

								fetchOptions = {
									method: method,
									url: url,
									body: body,
									headers: headers,
									query: query
								};
								_context.next = 8;
								return this.request(omitBy(mapOnFetchOneRequest(fetchOptions), isUndefined));

							case 8:
								res = _context.sent;
								_context.next = 11;
								return mapOnFetchOneResponse(res);

							case 11:
								data = _context.sent;

								runInAction(function () {
									_this2.cache.set(cacheKey, data);
									_this2.isFetching = false;
								});
								return _context.abrupt('return', data);

							case 14:
							case 'end':
								return _context.stop();
						}
					}
				}, _callee, this);
			}));

			function fetch() {
				return _ref2.apply(this, arguments);
			}

			return fetch;
		}()
	}, {
		key: 'setSelectedKeys',
		value: function setSelectedKeys(keys) {
			this.selectedKeys = keys;
		}
	}, {
		key: 'clearCache',
		value: function clearCache() {
			this.cache.clear();
		}
	}, {
		key: 'refresh',
		value: function refresh() {
			this.clearCache();
			this.call('fetch');
		}
	}, {
		key: 'getData',
		value: function getData() {
			return this.data;
		}
	}, {
		key: 'cacheKey',
		get: function get() {
			return JSON.stringify(toJS(this.query));
		}
	}, {
		key: 'data',
		get: function get() {
			return this.cache.get(this.cacheKey);
		}
	}]);

	return DataDetailStore;
}(BaseDataStore), (_descriptor = _applyDecoratedDescriptor(_class.prototype, 'isFetching', [observable], {
	enumerable: true,
	initializer: function initializer() {
		return false;
	}
}), _applyDecoratedDescriptor(_class.prototype, 'cacheKey', [computed], Object.getOwnPropertyDescriptor(_class.prototype, 'cacheKey'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'data', [computed], Object.getOwnPropertyDescriptor(_class.prototype, 'data'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'fetch', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'fetch'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'setSelectedKeys', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'setSelectedKeys'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'clearCache', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'clearCache'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'refresh', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'refresh'), _class.prototype)), _class);
export { DataDetailStore as default };
